#ifndef MainWindow_h
#define MainWindow_h

#include "YumIO.h"
#include <QtGui/QMainWindow>
#include <QtGui/QLineEdit>
#include <QtGui/QIcon>
#include <QtGui/QComboBox>
#include <QtGui/QPushButton>
#include <QtGui/QCheckBox>
#include "HMenu.h"
#include <QtGui/QAction>
#include "PackageTableView.h"
#include "RepoEditorDialog.h"
#include "LogWindow.h"
#include "YumConfIO.h"
#include "YumReposUsed.h"

class MainWindow : public QMainWindow {
   Q_OBJECT
public:
   explicit MainWindow(QWidget*  parent);
public:
   void setVisible(bool  visible);
protected:
   void setReady(bool  ready);
public slots:
   void resize();
   void refresh();
   void reposChanged();
protected slots:
   void initialize();
   void quit();
   void displayLog();
   void editRepositories();
   void about();
   void filtersearch();
   void currentChanged      (int  currentRow,
                             int  previousRow);
   void stateChanged        (int  row = -1);
   void modeChanged         (int  index);
   void collectedExtraData  ();
   void stateFilterChanged  (int  index);
   void groupsFilterChanged (int  checked);
   void selectUpdateAll();
   void clearActions();
   void apply();
protected:
   void prepareFilterSearch();
protected:
   QSize sizeHint() const;
protected:
   void createMenuBar();
   void createMainArea();
protected:
   QIcon  updateAllIcon;
   QIcon  clearIcon;
   QIcon  checkIcon;
protected:
   YumIO*                yumIO;
   YumConfIO*            yumConfIO;
   YumReposUsed          yumReposUsed;
protected:
   HMenu*                programMenu;
   QAction*              quitAction;
   HMenu*                repoMenu;
   QAction*              editAction;
   QWidget*              packageTableConfig;
   QComboBox*            modeComboBox;
   QLineEdit*            controlEdit;
   QPushButton*          controlButton;
   QComboBox*            stateComboBox;
   QCheckBox*            groupsCheckBox;
   PackageTable::Model*  packageTableModel;
   PackageTable::View*   packageTableView;
   QPushButton*          describeButton;
   QPushButton*          applyButton;
protected:
   RepoEditor::Dialog*  repoEditorDialog;
   Log::Window*         logWindow;
};

#endif
