#ifndef RepoEditorDialog_h
#define RepoEditorDialog_h

#include "HDialog.h"
#include "RepoEditorConfig.h"
#include "RepoEditorModel.h"
#include "RepoEditorView.h"
#include "YumConfIO.h"
#include <QtGui/QPushButton>
#include <QtGui/QLabel>
#include <QtGui/QPalette>
#include "YumConfIO.h"
#include "YumReposUsed.h"

namespace RepoEditor {

   // The repository editor dialog, for configuring the set of yum repositories

   // Avoid subclassing from QDialog because that comes with the "default
   // button" baggage which doesn't make any sense for this dialog.  Note
   // that keyPressEvent still supports using Escape to bail out of the
   // this dialog, though.
   class Dialog : public HDialog {
      Q_OBJECT
   public:
      explicit Dialog(YumConfIO*     yumConfIO,
                      QWidget*       parent);
   public slots:
      void setVisible(bool visible);
   signals:
      void reposChanged();
   protected slots:
      void currentChanged(int  currentRow,
                          int  previousRow);
      void useChanged();
      void entryChanged();
      void add();
      void copy();
      void remove();
   protected slots:
      void resetAll();
      void reset();
      void cancel();
      bool apply();
      void ok();
   protected:
      bool     hasEmptyId();
      QString  getDuplicateId();
   protected:
      void updateStatusLabel   ();
      void setEntryToOldId     (QString  oldId);
      void setEntryHasChanged  (bool     value);
      void setConfigHasChanged (bool     value);
   protected:
      QWidget*      parent;
      Model*        model;
      View*         view;
      QPushButton*  copyButton;
      QPushButton*  removeButton;
      QLabel*       statusLabel;
      QPushButton*  resetButton;
      QPushButton*  resetAllButton;
      QPushButton*  applyButton;
      Config*       config;
   protected:
      QPalette  statusLabelDefaultPalette;
   protected:
      YumConfIO*     yumConfIO;
      YumReposUsed   originalYumReposUsed;
   protected:
      bool  useHasChanged;
      bool  entryHasChanged;
      bool  configHasChanged;
      bool  applied;
   };

};

#endif
